@@ -26,7 +26,7 @@ def main(config: dict):
 		# Dictionary to group sound variants
 		sound_groups: dict[str, list[str]] = defaultdict(list)
 
-		for sound in sounds_names:
+		def handle_sound(sound: str) -> None:
 			rel_sound: str = sound.replace(sounds_folder + "/", "")
 
 			# Get sound without spaces and special characters
@@ -47,9 +47,12 @@ def main(config: dict):
 				# Not a numbered variant, add as individual sound
 				sound_groups[sound_file_no_ext] = [sound_file_no_ext]
 
+		# Process sounds in parallel
+		stp.multithreading(handle_sound, sounds_names, max_workers=min(32, len(sounds_names)))
+
 		# Create sounds.json with grouped sounds
 		sounds_json: dict = {}
-		for base_name, variants in sound_groups.items():
+		for base_name, variants in sorted(sound_groups.items()):
 			# Convert directory separators to dots for the sound ID
 			sound_id: str = base_name
 
@@ -70,6 +73,6 @@ def main(config: dict):
 		write_file(f"{config['build_resource_pack']}/assets/{config['namespace']}/sounds.json", stp.super_json_dump(sounds_json))
 
 		total_time: float = time.perf_counter() - start_time
-		stp.info(f"All sounds in '{sounds_folder}/' have been copied to the resource pack in {total_time:.5f}s")
+		stp.info(f"All sounds in '{stp.replace_tilde(sounds_folder)}/' have been copied to the resource pack in {total_time:.5f}s")
 
 
